==> odoo10_addon_stock_reserve-10.0.1.0.0.99.dev13-py2-none-any.whl: odoo/addons/stock_reserve/__manifest__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    Author: Guewen Baconnier
#    Copyright 2013 Camptocamp SA
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

{'name': 'Stock Reservation',
 'summary': 'Stock reservations on products',
 'version': '10.0.1.0.0',
 'author': "Camptocamp,Odoo Community Association (OCA)",
 'category': 'Warehouse',
 'license': 'AGPL-3',
 'complexity': 'normal',
 'images': [],
 'website': "http://www.camptocamp.com",
 'depends': ['stock',
             ],
 'demo': [],
 'data': ['view/stock_reserve.xml',
          'view/product.xml',
          'data/stock_data.xml',
          'security/ir.model.access.csv',
          ],
 'auto_install': False,
 'test': ['test/stock_reserve.yml',
          ],
 'installable': True,
 }

==> odoo10_addon_stock_reserve-10.0.1.0.1.99.dev3-py2-none-any.whl: odoo/addons/stock_reserve/__manifest__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    Author: Guewen Baconnier
#    Copyright 2013 Camptocamp SA
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

{'name': 'Stock Reservation',
 'summary': 'Stock reservations on products',
 'version': '10.0.1.0.1',
 'author': "Camptocamp,Odoo Community Association (OCA)",
 'category': 'Warehouse',
 'license': 'AGPL-3',
 'complexity': 'normal',
 'images': [],
 'website': "https://github.com/OCA/stock-logistics-warehouse",
 'depends': ['stock',
             ],
 'demo': [],
 'data': ['view/stock_reserve.xml',
          'view/product.xml',
          'data/stock_data.xml',
          'security/ir.model.access.csv',
          ],
 'auto_install': False,
 'test': ['test/stock_reserve.yml',
          ],
 'installable': True,
 }
